###################################################
### chunk number 1: 
###################################################
options(width=74)
library(xtable)


###################################################
### chunk number 2: <
###################################################
library(rcdk)


###################################################
### chunk number 3:  eval=FALSE
###################################################
## library(help=rcdk)


###################################################
### chunk number 4:  eval=FALSE
###################################################
## mols <- load.molecules( c('data1.sdf', '/some/path/data2.sdf') )


###################################################
### chunk number 5: 
###################################################
smile <- 'c1ccccc1CC(=O)C(N)CC1CCCCOC1'
mol <- parse.smiles(smile)


###################################################
### chunk number 6: 
###################################################
smiles <- c('CCC', 'c1ccccc1', 'CCCC(C)(C)CC(=O)NC')
sp <- get.smiles.parser()
mols <- sapply(smiles, parse.smiles, parser=sp)


###################################################
### chunk number 7:  eval=FALSE
###################################################
## write.molecules(mols, filename='mymols.sdf')


###################################################
### chunk number 8:  eval=FALSE
###################################################
## write.molecules(mols, filename='mymols.sdf', together=FALSE)


###################################################
### chunk number 9: 
###################################################
get.smiles(mols[[1]])
unlist(lapply(mols, get.smiles))


###################################################
### chunk number 10:  eval=FALSE
###################################################
## sp <- get.smiles.parser()
## smiles <- c('CCC', 'CCN', 'CCN(C)(C)',
##             'c1ccccc1Cc1ccccc1',
##             'C1CCC1CC(CN(C)(C))CC(=O)CC')
## mols <- sapply(smiles, parse.smiles, parser=sp)
## view.molecule.2d(mols[[1]])
## view.molecule.2d(mols)


###################################################
### chunk number 11:  eval=FALSE
###################################################
## dframe <- data.frame(x = runif(4),
##                      toxicity = factor(c('Toxic', 'Toxic', 'Nontoxic', 'Nontoxic')),
##                      solubility = c('yes', 'yes', 'no', 'yes'))
## view.table(mols[1:4], dframe)


###################################################
### chunk number 12: 
###################################################
mol <- parse.smiles('c1ccccc1', parser=sp)
set.property(mol, "title", "Molecule 1")
set.property(mol, "hvyAtomCount", 6)
get.property(mol, "title")


###################################################
### chunk number 13: 
###################################################
get.properties(mol)


###################################################
### chunk number 14:  eval=FALSE
###################################################
## write.molecules(mol, 'tagged.sdf', write.props=TRUE)


###################################################
### chunk number 15: 
###################################################
mol <- parse.smiles('c1ccccc1C(Cl)(Br)c1ccccc1')
atoms <- get.atoms(mol)
bonds <- get.bonds(mol)
cat('No. of atoms =', length(atoms), '\n')
cat('No. of bonds =', length(bonds), '\n')


###################################################
### chunk number 16: 
###################################################
unlist(lapply(atoms, get.symbol))


###################################################
### chunk number 17: 
###################################################
coords <- get.point3d(atoms[[1]])


###################################################
### chunk number 18:  eval=FALSE
###################################################
## coords <- do.call('rbind', lapply(atoms, get.point3d))


###################################################
### chunk number 19:  eval=FALSE
###################################################
## if ( any(apply(coords, 2, function(x) length(unique(x))) == 1) ) {
##   print("molecule is flat")
## }


###################################################
### chunk number 20: 
###################################################
dc <- get.desc.categories()
dc


###################################################
### chunk number 21: 
###################################################
dn <- get.desc.names(dc[1])


###################################################
### chunk number 22: 
###################################################
aDesc <- eval.desc(mol, dn[1])
allDescs <- eval.desc(mol, dn)


###################################################
### chunk number 23: 
###################################################
data(bpdata)
mols <- sapply(bpdata[,1], parse.smiles, parser=sp)
descNames <- unique(unlist(sapply(get.desc.categories(), get.desc.names)))
descs <- eval.desc(mols, descNames) 
class(descs)
dim(descs)


###################################################
### chunk number 24: 
###################################################
mol <- parse.smiles('CC(=O)CC(=O)NCN')
convert.implicit.to.explicit(mol)
get.tpsa(mol)
get.xlogp(mol)
get.alogp(mol)


###################################################
### chunk number 25:  eval=FALSE
###################################################
## descs <- descs[, !apply(descs, 2, function(x) any(is.na(x)) )]
## descs <- descs[, !apply( descs, 2, function(x) length(unique(x)) == 1 )]
## r2 <- which(cor(descs)^2 > .6, arr.ind=TRUE)
## r2 <- r2[ r2[,1] > r2[,2] , ]
## descs <- descs[, -unique(r2[,2])]


###################################################
### chunk number 26: 
###################################################
model <- lm(BP ~ khs.sCH3 + khs.sF + apol + nHBDon, data.frame(bpdata, descs))
summary(model)


###################################################
### chunk number 27: 
###################################################
par(mar=c(4.3,4.3,1,1),cex.lab=1.3, pty='s')
plot(bpdata$BP, model$fitted, pch=19, 
     ylab='Predicted BP', xlab='Observed BP',
     xlim=range(bpdata$BP), ylim=range(bpdata$BP))
abline(0,1, col='red')


###################################################
### chunk number 28: 
###################################################
sp <- get.smiles.parser()
smiles <- c('CCC', 'CCN', 'CCN(C)(C)', 
            'c1ccccc1Cc1ccccc1',
            'C1CCC1CC(CN(C)(C))CC(=O)CC')
mols <- sapply(smiles, parse.smiles, parser=sp)
fp <- get.fingerprint(mols[[1]], type='maccs')


###################################################
### chunk number 29: 
###################################################
mols <- sapply(bpdata[1:50,1], parse.smiles, parser=sp) 
fps <- lapply(mols, get.fingerprint, type='extended') 
fp.sim <- fp.sim.matrix(fps, method='tanimoto') 
fp.dist <- 1 - fp.sim 


###################################################
### chunk number 30: 
###################################################
clustering <- hclust(as.dist(fp.dist))
plot(clustering, main='A Clustering of the BP dataset')


###################################################
### chunk number 31: 
###################################################
query.mol <- parse.smiles('CC(=O)', parser=sp)
target.mols <- sapply(bpdata[,1], parse.smiles, parser=sp)
query.fp <- get.fingerprint(query.mol, type='maccs')
target.fps <- lapply(target.mols, get.fingerprint, type='maccs')
sims <- unlist(lapply(target.fps, 
                      distance, 
                      fp2=query.fp, method='tanimoto'))
hits <- which(sims > 0.3)


###################################################
### chunk number 32: 
###################################################
d <- data.frame(SMILES=bpdata[hits,1], Similarity=sims[hits])
row.names(d) <- NULL
d <- d[sort.list(d[,2], dec=TRUE),]
xtable(d, label="tab:sims", 
       caption="Summary of molecules in the BP dataset that are greater than 0.3 similar to acetaldehyde")


###################################################
### chunk number 33: 
###################################################
sp <- get.smiles.parser()
molecule <- sapply('N', parse.smiles, parser=sp)[[1]]
convert.implicit.to.explicit(molecule)
formula <- get.mol2formula(molecule,charge=0)


###################################################
### chunk number 34: 
###################################################
formula@mass


###################################################
### chunk number 35: 
###################################################
formula@charge


###################################################
### chunk number 36: 
###################################################
formula@isotopes


###################################################
### chunk number 37: 
###################################################
formula@objectJ


###################################################
### chunk number 38: 
###################################################
formula@string


###################################################
### chunk number 39:  eval=FALSE
###################################################
## formula <- set.charge.formula(formula, charge=1)


###################################################
### chunk number 40: 
###################################################
formula <- get.formula('NH4', charge = 1);
formula


###################################################
### chunk number 41: 
###################################################
mfSet <- generate.formula(18.03383, window=1, 
		elements=list(c("C",0,50),c("H",0,50),c("N",0,50)), 
		validation=FALSE);
for (i in 1:length(mfSet)) {
  print(mfSet[i])
}


###################################################
### chunk number 42: 
###################################################
formula <- get.formula('NH4', charge = 0);
isvalid.formula(formula,rule=c("nitrogen","RDBE"))


###################################################
### chunk number 43: 
###################################################
formula <- get.formula('CHCl3', charge = 0) 
isotopes <- get.isotopes.pattern(formula,minAbund=0.1)
isotopes


###################################################
### chunk number 44: 
###################################################
plot(isotopes, type="h", xlab="m/z", ylab="Intensity")


